pub struct MetaConfig {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for MetaConfig
impl Clone for MetaConfig
Sourcefn clone(&self) -> MetaConfig
fn clone(&self) -> MetaConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaConfig
impl Debug for MetaConfig
Sourceimpl Default for MetaConfig
impl Default for MetaConfig
Sourcefn default() -> MetaConfig
fn default() -> MetaConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MetaConfig
impl<'de> Deserialize<'de> for MetaConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MetaConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MetaConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetaConfig
impl JsonSchema for MetaConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MetaConfig
impl PartialEq for MetaConfig
Sourcefn eq(&self, other: &MetaConfig) -> bool
fn eq(&self, other: &MetaConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MetaConfig
impl Serialize for MetaConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for MetaConfig
impl StructuralPartialEq for MetaConfig